==> edupsyadmin-3.1.2.tar.gz: edupsyadmin-3.1.2/alembic/env.py <==
import os
from logging.config import fileConfig

from platformdirs import user_data_path
from sqlalchemy import engine_from_config, pool

from alembic import context
from edupsyadmin import __version__
from edupsyadmin.api.clients import Base

# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config

# Interpret the config file for Python logging.
# This line sets up loggers basically.
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# add your model's MetaData object here
# for 'autogenerate' support
# from myapp import mymodel
# target_metadata = mymodel.Base.metadata
target_metadata = Base.metadata

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    # I cannot set the url in the ini file because the path includes the app version
    # url = config.get_main_option("sqlalchemy.url")
    USER_DATA_DIR = user_data_path(
        appname="edupsyadmin", version=__version__, ensure_exists=True
    )
    url = "sqlite:///" + os.path.join(USER_DATA_DIR, "edupsyadmin.db")

    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online() -> None:
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    # I cannot set the url in the ini file because the path includes the app version
    # connectable = engine_from_config(
    #     config.get_section(config.config_ini_section, {}),
    #     prefix="sqlalchemy.",
    #     poolclass=pool.NullPool,
    # )
    USER_DATA_DIR = user_data_path(
        appname="edupsyadmin", version=__version__, ensure_exists=True
    )
    url = "sqlite:///" + os.path.join(USER_DATA_DIR, "edupsyadmin.db")
    connectable = engine_from_config(
        {"sqlalchemy.url": url},
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(connection=connection, target_metadata=target_metadata)

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()

==> edupsyadmin-5.1.0.tar.gz: edupsyadmin-5.1.0/alembic/env.py <==
import os
from logging.config import fileConfig

from platformdirs import user_data_path
from sqlalchemy import engine_from_config, pool

from alembic import context
from edupsyadmin import __version__
from edupsyadmin.db import Base

# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config

# Interpret the config file for Python logging.
# This line sets up loggers basically.
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# add your model's MetaData object here
# for 'autogenerate' support
# from myapp import mymodel
# target_metadata = mymodel.Base.metadata
target_metadata = Base.metadata

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    # I cannot set the url in the ini file because the path includes the app version
    # url = config.get_main_option("sqlalchemy.url")
    USER_DATA_DIR = user_data_path(
        appname="edupsyadmin", version=__version__, ensure_exists=True
    )
    url = "sqlite:///" + os.path.join(USER_DATA_DIR, "edupsyadmin.db")

    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online() -> None:
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    # I cannot set the url in the ini file because the path includes the app version
    # connectable = engine_from_config(
    #     config.get_section(config.config_ini_section, {}),
    #     prefix="sqlalchemy.",
    #     poolclass=pool.NullPool,
    # )
    USER_DATA_DIR = user_data_path(
        appname="edupsyadmin", version=__version__, ensure_exists=True
    )
    url = "sqlite:///" + os.path.join(USER_DATA_DIR, "edupsyadmin.db")
    connectable = engine_from_config(
        {"sqlalchemy.url": url},
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(connection=connection, target_metadata=target_metadata)

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()
